@@ -7,7 +7,7 @@ Attean::API - Utility package for loading all Attean role packages.
 
 =head1 VERSION
 
-This document describes Attean::API version 0.002
+This document describes Attean::API version 0.007
 
 =head1 SYNOPSIS
 
@@ -21,37 +21,64 @@ in the Attean::API namespace.
 
 =cut
 
-package Attean::API::ResultOrTerm 0.001 {
+package Attean::API::ResultOrTerm 0.007 {
 	use Moo::Role;
 }
 
-package Attean::API::BlankOrIRI 0.001 {
+package Attean::API::BlankOrIRI 0.007 {
 	use Moo::Role;
 }
 
-package Attean::API::TermOrVariable 0.001 {
+package Attean::API::TermOrVariable 0.007 {
 	use Moo::Role;
+	use Sub::Install;
+	use Sub::Util qw(set_subname);
+	use namespace::clean;
+
 	sub equals {
 		my ($a, $b)	= @_;
 		return ($a->as_string eq $b->as_string);
 	}
+	
+	BEGIN {
+		my %types	= (
+			variable	=> 'Variable',
+			blank		=> 'Blank',
+			literal		=> 'Literal',
+			resource	=> 'IRI',
+			iri			=> 'IRI',
+		);
+		while (my ($name, $role) = each(%types)) {
+			my $method	= "is_$name";
+			my $code	= sub { return shift->does("Attean::API::$role") };
+			Sub::Install::install_sub({
+				code	=> set_subname($method, $code),
+				as		=> $method
+			});
+		}
+	}
 }
 
-package Attean::Mapper 0.001 {
+package Attean::Mapper 0.007 {
 	use Moo::Role;
 	requires 'map'; # my $that = $object->map($this)
 }
 
-package Attean::API::Variable 0.001 {
+package Attean::API::Variable 0.007 {
 	use Moo::Role;
 	with 'Attean::API::TermOrVariable';
+	sub as_sparql {
+		my $self	= shift;
+		return '?' . $self->value;
+	}
+	
 	sub as_string {
 		my $self	= shift;
 		return '?' . $self->value;
 	}
 }
 
-package Attean::API::CanonicalizingBindingSet 0.001 {
+package Attean::API::CanonicalizingBindingSet 0.007 {
 	use Moo::Role;
 	use Attean::RDF;
 	use namespace::clean;
@@ -142,7 +169,7 @@ package Attean::API::CanonicalizingBindingSet 0.001 {
 	}
 }
 
-package Attean::API 0.001 {
+package Attean::API 0.007 {
 	use Attean::API::Term;
 	use Attean::API::Store;
 	use Attean::API::Model;
@@ -151,7 +178,8 @@ package Attean::API 0.001 {
 	use Attean::API::Serializer;
 	use Attean::API::Query;
 	use Attean::API::Expression;
-
+	use Attean::API::Plan;
+	
 	use Attean::Variable;
 	use Attean::Blank;
 	use Attean::IRI;
